package de.ids_mannheim.korap.openthesaurus;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.stereotype.Component;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.List;
import java.util.Map;

import static de.ids_mannheim.korap.openthesaurus.OpenThesaurusData.getFile;
import static de.ids_mannheim.korap.openthesaurus.ThesaurusDictionary.createThesaurusDictionary;

@Component
public class DoOnStartup implements ApplicationRunner {

    public static Map<String, List<List<String>>> thesaurusDict;

    @Value("${update}")
    boolean update;

    @Value("${openthesaurus}")
    String openthesaurus;

    @Override
    public void run(ApplicationArguments args) throws IOException {
        //boolean update = args.containsOption("update");
        //boolean openthesaurus = args.containsOption("openthesaurus");

        if (update) {
            String url = "https://www.openthesaurus.de/export/OpenThesaurus-Textversion.zip";
            String thesaurusFilepath = "data/openthesaurus.txt";

            getFile(url, thesaurusFilepath);

            InputStream thesaurusInputStream = new FileInputStream(thesaurusFilepath);
            thesaurusDict = createThesaurusDictionary(thesaurusInputStream);
        }
        else if(!openthesaurus.isBlank()) {
            thesaurusDict = createThesaurusDictionary(openthesaurus);
        }
        else if(!Files.exists(Path.of("data", "openthesaurus.txt"))){
            String message = "You selected update=false, but didn't provide any data! No cached data are available!";
            throw new RuntimeException(message);
        }
    }
}
